
.. _amrclaw_tests_acoustics_2d_forwardproblem:

Two-dimensional acoustics adjoint-flagging forward problem 
===========================================================

Quick regression test version:  regression_tests.py

* Runs only up to time t=0.5.
* Checks sum of t values and q values at three different gauges.
  Tests pass if these agree with specified values in regression_tests.py.
